"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeUi5RepositoryFiles = exports.writeUi5RepositoryFile = exports.addUi5Dependency = void 0;
const path_1 = require("path");
const fast_glob_1 = __importDefault(require("fast-glob"));
const os_1 = require("os");
const project_access_1 = require("@sap-ux/project-access");
const constants_1 = require("./constants");
const semver_1 = require("semver");
/**
 * Adds a new UI5 dependency to the package.json.
 * No longer required for `@ui5/cli` v3 and above.
 *
 * @param fs - the memfs editor instance
 * @param basePath - the base path
 * @param depName - the dependency name
 */
function addUi5Dependency(fs, basePath, depName) {
    const filePath = (0, path_1.join)(basePath, project_access_1.FileName.Package);
    const packageJson = (fs.readJSON(filePath) ?? {});
    const ui5CliVersion = (0, semver_1.coerce)(packageJson?.devDependencies?.[constants_1.UI5_CLI_LIB]);
    if (ui5CliVersion && (0, semver_1.satisfies)(ui5CliVersion, `>=${constants_1.UI5_CLI_MIN_VERSION}`)) {
        // https://sap.github.io/ui5-tooling/v3/updates/migrate-v3/#changes-to-dependency-configuration
        return;
    }
    packageJson.ui5 = packageJson.ui5 ?? {};
    packageJson.ui5.dependencies = packageJson.ui5.dependencies ?? [];
    if (!packageJson.ui5.dependencies.includes(depName)) {
        packageJson.ui5.dependencies.push(depName);
    }
    fs.writeJSON(filePath, packageJson);
}
exports.addUi5Dependency = addUi5Dependency;
/**
 * Writes the UI5 repository file.
 *
 * @param fs - the memfs editor instance
 * @param basePath - the base path
 * @param ui5RepositoryFile - the UI5 repository file
 * @param addContent - the content to be added
 */
const writeUi5RepositoryFile = (fs, basePath, ui5RepositoryFile, addContent) => {
    const filePath = (0, path_1.join)(basePath, ui5RepositoryFile);
    let content;
    if (fs.exists(filePath)) {
        content = fs.read(filePath);
        if (!content.includes(addContent)) {
            content = `${content}\n${addContent}`;
        }
    }
    else {
        content = addContent;
    }
    fs.write(filePath, content);
};
exports.writeUi5RepositoryFile = writeUi5RepositoryFile;
/**
 * Writes the UI5 repository files if typescript files are found.
 *
 * @param fs - the memfs editor instance
 * @param basePath - the base path
 */
const writeUi5RepositoryFiles = async (fs, basePath) => {
    const webappPath = await (0, project_access_1.getWebappPath)(basePath);
    const typescriptPattern = (0, path_1.join)(webappPath, '/**/*.ts');
    const normalisedPath = (0, os_1.platform)() === 'win32' ? typescriptPattern.replace(/\\/g, '/') : typescriptPattern;
    const typeScriptFilesPaths = await (0, fast_glob_1.default)(normalisedPath);
    if (typeScriptFilesPaths?.length > 0) {
        (0, exports.writeUi5RepositoryFile)(fs, webappPath, constants_1.UI5_REPO_TEXT_FILES, '^.*.ts$');
    }
};
exports.writeUi5RepositoryFiles = writeUi5RepositoryFiles;
//# sourceMappingURL=file.js.map